@@ -3,7 +3,7 @@
  * Author: Brent Hendricks
  * Project: GGZ Text Client 
  * Date: 9/26/00
- * $Id: output.c 7270 2005-06-10 12:39:41Z josef $
+ * $Id: output.c 8845 2007-01-06 23:50:21Z oojah $
  *
  * Functions for display text/messages
  *
@@ -120,6 +120,10 @@ void output_display_help(void)
 	output_text(_("--- /who                                    List current player in the room"));
 	output_text(_("--- /wall <msg>                             Admin only command, broadcast to all rooms"));
 	output_text(_("--- /log <logfile>                          Log conversation into logfile"));
+	output_text(_("--- /admin ...                              Administrative commands"));
+	output_text(_("---    ... gag <player>                     Global ignore on messages from <player>"));
+	output_text(_("---    ... ungag <player>                   Revert gagging"));
+	output_text(_("---    ... kick <player> <reason>           Kick <player> from server"));
 }
 
 void output_banner(void)
@@ -272,12 +276,14 @@ void output_rooms(void)
 		room = ggzcore_server_get_nth_room(server, i);
 		type = ggzcore_room_get_gametype(room);
 		if (type)
-			output_text(_("-- Room %d : %s (%s)"), i,
-				    ggzcore_room_get_name(room),
-				    ggzcore_gametype_get_name(type));
+			output_text(_("-- Room %d : %s (%s) (Players: %d)"), i,
+					ggzcore_room_get_name(room),
+					ggzcore_gametype_get_name(type),
+					ggzcore_room_get_num_players(room));
 		else
-			output_text(_("-- Room %d : %s"), i,
-				    ggzcore_room_get_name(room));
+			output_text(_("-- Room %d : %s (Players: %d)"), i,
+					ggzcore_room_get_name(room),
+					ggzcore_room_get_num_players(room));
 	}
 }
 
@@ -322,9 +328,10 @@ void output_players(void)
 			ggzcore_player_get_name(player),
 			table ? _("at table %d") : "",
 			type == GGZ_PLAYER_ADMIN ? _("(Administrator)") :
+			((type == GGZ_PLAYER_HOST) ? _("(Host)") :
 			((type == GGZ_PLAYER_BOT) ? _("(Bot)") :
 			((type == GGZ_PLAYER_GUEST) ? _("(Guest)") :
-			"")));
+			""))));
 	}
 }
 
