@@ -37,6 +37,9 @@ void output_prompt(void);
 void output_text(char* fmt, ...)
      ggz__attribute((format(printf, 1, 2)));
 
+void output_debug(char* fmt, ...)
+     ggz__attribute((format(printf, 1, 2)));
+
 void output_chat(GGZChatType type, const char *player, const char *message);
 
 void output_players(void);
@@ -57,4 +60,11 @@ void output_display_help(void);
 
 void output_resize(void);
 
+void output_enable(int enabled);
+
+void output_log_init(const char *logfile);
+
+void output_log(char* fmt, ...)
+     ggz__attribute((format(printf, 1, 2)));
+
 #endif /*__OUTPUT_H__*/
