@@ -3,7 +3,7 @@
  * Author: Brent Hendricks
  * Project: GGZ Text Client 
  * Date: 9/26/00
- * $Id: server.h,v 1.12 2002/10/11 19:35:05 jdorje Exp $
+ * $Id: server.h 6586 2005-01-02 15:30:59Z josef $
  *
  * Functions for handling server events
  *
@@ -26,6 +26,10 @@
 
 #include <ggzcore.h>
 
+#define COMMAND_CONNECT 0
+#define COMMAND_LIST 1
+#define COMMAND_JOIN 2
+
 void server_init(char *host, int port, GGZLoginType type, char* login, char* password);
 
 void server_logout(void);
@@ -33,5 +37,12 @@ void server_disconnect(void);
 
 void server_destroy(void);
 
+void server_workinprogress(int command, int progress);
+void server_progresswait(void);
+
 /* Pointer to the current server */
 extern GGZServer *server;
+
+extern int players_on_server;
+extern int players_in_room;
+
